==> pyconnectwise-0.2.4.tar.gz: pyconnectwise-0.2.4/src/pyconnectwise/endpoints/manage/CompanyMarketDescriptionsEndpoint.py <==
from pyconnectwise.models.base.message_model import GenericMessageModel
from pyconnectwise.endpoints.base.connectwise_endpoint import ConnectWiseEndpoint
from pyconnectwise.responses.paginated_response import PaginatedResponse
from typing import Any
from pyconnectwise.endpoints.manage.CompanyMarketDescriptionsIdEndpoint import CompanyMarketDescriptionsIdEndpoint
from pyconnectwise.endpoints.manage.CompanyMarketDescriptionsCountEndpoint import CompanyMarketDescriptionsCountEndpoint
from pyconnectwise.endpoints.manage.CompanyMarketDescriptionsInfoEndpoint import CompanyMarketDescriptionsInfoEndpoint
from pyconnectwise.models.manage.MarketDescriptionModel import MarketDescriptionModel

class CompanyMarketDescriptionsEndpoint(ConnectWiseEndpoint):
    def __init__(self, client, parent_endpoint=None):
        super().__init__(client, "marketDescriptions", parent_endpoint=parent_endpoint)
        
        self.count = self.register_child_endpoint(
            CompanyMarketDescriptionsCountEndpoint(client, parent_endpoint=self)
        )
        self.info = self.register_child_endpoint(
            CompanyMarketDescriptionsInfoEndpoint(client, parent_endpoint=self)
        )
    
    
    def id(self, id: int) -> CompanyMarketDescriptionsIdEndpoint:
        """
        Sets the ID for this endpoint and returns an initialized CompanyMarketDescriptionsIdEndpoint object to move down the chain.

        Parameters:
            id (int): The ID to set.
        Returns:
            CompanyMarketDescriptionsIdEndpoint: The initialized CompanyMarketDescriptionsIdEndpoint object.
        """
        child = CompanyMarketDescriptionsIdEndpoint(self.client, parent_endpoint=self)
        child._id = id
        return child
    
    def paginated(self, page: int, page_size: int, params: dict[str, int | str] = {}) -> PaginatedResponse[MarketDescriptionModel]:
        """
        Performs a GET request against the /company/marketDescriptions endpoint and returns an initialized PaginatedResponse object.

        Parameters:
            page (int): The page number to request.
            page_size (int): The number of results to return per page.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            PaginatedResponse[MarketDescriptionModel]: The initialized PaginatedResponse object.
        """
        params["page"] = page
        params["pageSize"] = page_size
        return PaginatedResponse(
            super().make_request(
                "GET",
                params=params
            ),
            MarketDescriptionModel,
            self,
            page_size,
        )
    
    def get(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> list[MarketDescriptionModel]:
        """
        Performs a GET request against the /company/marketDescriptions endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            list[MarketDescriptionModel]: The parsed response data.
        """
        return self._parse_many(MarketDescriptionModel, super().make_request("GET", params=params).json())
        
    def post(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> MarketDescriptionModel:
        """
        Performs a POST request against the /company/marketDescriptions endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            MarketDescriptionModel: The parsed response data.
        """
        return self._parse_one(MarketDescriptionModel, super().make_request("POST", params=params).json())

==> pyconnectwise-0.2.5.tar.gz: pyconnectwise-0.2.5/src/pyconnectwise/endpoints/manage/CompanyMarketDescriptionsEndpoint.py <==
from pyconnectwise.models.base.message_model import GenericMessageModel
from pyconnectwise.endpoints.base.connectwise_endpoint import ConnectWiseEndpoint
from pyconnectwise.responses.paginated_response import PaginatedResponse
from typing import Any
from pyconnectwise.endpoints.manage.CompanyMarketDescriptionsIdEndpoint import CompanyMarketDescriptionsIdEndpoint
from pyconnectwise.endpoints.manage.CompanyMarketDescriptionsCountEndpoint import CompanyMarketDescriptionsCountEndpoint
from pyconnectwise.endpoints.manage.CompanyMarketDescriptionsInfoEndpoint import CompanyMarketDescriptionsInfoEndpoint
from pyconnectwise.models.manage.MarketDescriptionModel import MarketDescriptionModel

class CompanyMarketDescriptionsEndpoint(ConnectWiseEndpoint):
    def __init__(self, client, parent_endpoint=None):
        super().__init__(client, "marketDescriptions", parent_endpoint=parent_endpoint)
        
        self.count = self.register_child_endpoint(
            CompanyMarketDescriptionsCountEndpoint(client, parent_endpoint=self)
        )
        self.info = self.register_child_endpoint(
            CompanyMarketDescriptionsInfoEndpoint(client, parent_endpoint=self)
        )
    
    
    def id(self, id: int) -> CompanyMarketDescriptionsIdEndpoint:
        """
        Sets the ID for this endpoint and returns an initialized CompanyMarketDescriptionsIdEndpoint object to move down the chain.

        Parameters:
            id (int): The ID to set.
        Returns:
            CompanyMarketDescriptionsIdEndpoint: The initialized CompanyMarketDescriptionsIdEndpoint object.
        """
        child = CompanyMarketDescriptionsIdEndpoint(self.client, parent_endpoint=self)
        child._id = id
        return child
    
    def paginated(self, page: int, page_size: int, params: dict[str, int | str] = {}) -> PaginatedResponse[MarketDescriptionModel]:
        """
        Performs a GET request against the /company/marketDescriptions endpoint and returns an initialized PaginatedResponse object.

        Parameters:
            page (int): The page number to request.
            page_size (int): The number of results to return per page.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            PaginatedResponse[MarketDescriptionModel]: The initialized PaginatedResponse object.
        """
        params["page"] = page
        params["pageSize"] = page_size
        return PaginatedResponse(
            super().make_request(
                "GET",
                params=params
            ),
            MarketDescriptionModel,
            self,
            page_size,
        )
    
    def get(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> list[MarketDescriptionModel]:
        """
        Performs a GET request against the /company/marketDescriptions endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            list[MarketDescriptionModel]: The parsed response data.
        """
        return self._parse_many(MarketDescriptionModel, super().make_request("GET", data=data, params=params).json())
        
    def post(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> MarketDescriptionModel:
        """
        Performs a POST request against the /company/marketDescriptions endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            MarketDescriptionModel: The parsed response data.
        """
        return self._parse_one(MarketDescriptionModel, super().make_request("POST", data=data, params=params).json())
